param([switch]$nobanner, [switch]$enable, [switch]$disable)

$action = ""

if ($enable -and $disable) {
    Throw "Both enable and disable selected"
}

if ($enable) {
    $action = "enable"
}

if ($disable) {
    $action = "disable"
}

# ASCII banner
if (!$nobanner) {
    Write-Host "                _        __                  "
    Write-Host "__   _____   __| | __ _ / _| ___  _ __   ___ "
    Write-Host "\ \ / / _ \ / _' |/ _' | |_ / _ \| '_ \ / _ \"
    Write-Host " \ V / (_) | (_| | (_| |  _| (_) | | | |  __/"
    Write-Host "  \_/ \___/ \__,_|\__,_|_|  \___/|_| |_|\___|"
    Write-Host ""
}

# Mode enabling file
$modefile = "DEMO.vf-log"
$modename = "Demo"

$identityName = "VodafoneGroupServices.VodafoneMobileBroadband"

Function GetAppName() {
    return get-appxpackage -name $identityName | Select -Property PackageFamilyName
}

Function GetPathToLocalAppData {
    $localAppDataVariable = Get-ChildItem Env:LOCALAPPDATA

    if(!$localAppDataVariable) {
        Throw "The environment variable 'LOCALAPPDATA' is not set"
    }

    $localAppDataPath = $localAppDataVariable.Value

    if (!(Test-Path -path $localAppDataPath))
    {
        Throw "The local app data path $localAppDataPath does not exist"
    }

    return $localAppDataPath
}

Function GetPathToLocalState {
    $appname = GetAppName
    $localAppDataPath = GetPathToLocalAppData 

    # Construct path to LocalState directory to put mode enabling files into
    $localstate = $localAppDataPath + "\Packages\" + $appname.PackageFamilyName + "\LocalState"

    return $localstate
}

Function DoEnableDisableChoice([string]$message) {
    $input = Read-Host $message;

    if($input -eq "e") {
        return "enable"
    }

    if($input -eq "d") {
        return "disable"
    }

    Throw "Illegal input '$input'. Select either 'e' to enable or 'd' to disable"
}

if ($action -eq "") {
    $action = DoEnableDisableChoice("Do you want to enable [E] or disable [D] $modename mode")
}

$localstate = GetPathToLocalState
# Check if LocalState directory exists, and create file if not already there
if (!(Test-Path $localstate)) {
    Throw "Could not find application package, is application installed?"
} elseif ($action -eq "enable") {
    if (Test-Path ($localstate + "\" + $modefile)) {
        Write-Host $modename "mode is already enabled"
    } else {
        New-Item -path $localstate -name $modefile -type file | Out-Null
        Write-Host $modename "mode enabled"
    }
} elseif ($action -eq "disable") {
    if (Test-Path ($localstate + "\" + $modefile)) {
        Remove-Item ($localstate + "\" + $modefile)
        Write-Host $modename "mode is disabled"
    } else {
        Write-Host $modename "mode is already disabled"
    }
} else {
    Throw ("Unknown action -- " + $action)
}
